<?php

/**
 * This file includes \QUI\Controls\Utils
 */

namespace QUI\Controls\Utils;

use function is_array;
use function is_object;
use function is_string;
use function method_exists;

/**
 * Class MetaList
 * - build meta data for controls
 * - <meta itemprop="" content="">
 */
class MetaList
{
    /**
     * @var array
     */
    protected array $items = [];

    /**
     * @param $itemprop
     * @param object|array $attributes
     */
    public function add($itemprop, object|array $attributes = []): void
    {
        $this->items[] = [
            'itemprop' => $itemprop,
            'attributes' => $attributes
        ];
    }

    /**
     * clears the meta list
     */
    public function clear(): void
    {
        $this->items = [];
    }

    /**
     * Create the meta block
     *
     * @return string
     */
    public function create(): string
    {
        $result = '';

        foreach ($this->items as $item) {
            $itemprop = $item['itemprop'];
            $attributes = $item['attributes'];
            $node = 'meta';
            $html = '';

            if (is_object($attributes)) {
                if (method_exists($attributes, 'create')) {
                    $result .= $attributes->create();
                }

                continue;
            }

            if (isset($attributes['nodeName'])) {
                $node = $attributes['nodeName'];
                unset($attributes['nodeName']);
            }

            if (isset($attributes['html'])) {
                $html = $attributes['html'];
                unset($attributes['html']);
            }


            if (is_array($attributes)) {
                $a = '';

                foreach ($attributes as $attr => $v) {
                    if (empty($v)) {
                        $a .= $attr . ' ';
                        continue;
                    }

                    $a .= $attr . '="' . $v . '" ';
                }

                $attributes = $a;
            } elseif (is_string($attributes)) {
                $attributes = ' content="' . $attributes . '"';
            } else {
                $attributes = '';
            }

            if (empty($html)) {
                $result .= '<' . $node . ' itemprop="' . $itemprop . '" ' . $attributes . ' />';
                continue;
            }

            $result .= '<' . $node . ' itemprop="' . $itemprop . '" ' . $attributes . '>';
            $result .= $html;
            $result .= '</' . $node . '>';
        }

        return $result;
    }
}
